style "chrome-gtk-frame" = "theme-default" {

    ChromeGtkFrame::frame-color	= "#B3C3DE"
    ChromeGtkFrame::inactive-frame-color = "#D1D1D1"
    ChromeGtkFrame::incognito-frame-color = "#B3C3DE"
    ChromeGtkFrame::incognito-inactive-frame-color = "#D1D1D1"

    ChromeGtkFrame::frame-gradient-size		= 50
    ChromeGtkFrame::frame-gradient-color		= "#E9E9E9"
    ChromeGtkFrame::inactive-frame-gradient-color	= "#E4E4E4"

    ChromeGtkFrame::scrollbar-trough-color 	= @bg_color
    ChromeGtkFrame::scrollbar-slider-normal-color 		= "#EBEBEB"
    ChromeGtkFrame::scrollbar-slider-prelight-color 	= "#F5F5F5"
}

class "ChromeGtkFrame" style "chrome-gtk-frame"


