style "gnome-system-monitor-menu" = "theme-menu" {
    bg[ACTIVE] = shade (0.75,@bg_color)
    GtkMenu::horizontal-padding = 1
    GtkMenu::vertical-padding = 1
}

widget_class "*Gnome-system-monitor*Menu*"                		style "gnome-system-monitor-menu"

