style "theme-default" {
  engine "equinox" {
    menubarborders      = 0 
    menubarstyle        = 0
  }
}

style "theme-toolbar-dark" = "theme-dark" { 
  bg[NORMAL] = shade(1.07, @bg_color_dark)
}

style "theme-panel" = "theme-dark" {
  bg_pixmap[NORMAL] = "images/panel_bg_global.png"
}

